import logging
import re

from music.constants import VARIOUS_ARTIST_DICT

logger = logging.getLogger(__name__)

def clean_artist_name(name: str) -> str:
    """Remove featured names from artist string."""
    if "feat." in name.lower():
        name = re.split("feat.", name, flags=re.IGNORECASE)[0].strip()
    if "featuring" in name.lower():
        name = re.split("featuring", name, flags=re.IGNORECASE)[0].strip()
    if "&" in name.lower():
        name = re.split("&", name, flags=re.IGNORECASE)[0].strip()

    return name

def get_or_create_various_artists() -> "Artist":
    from music.models import Artist

    artist = Artist.objects.filter(name="Various Artists").first()
    if not artist:
        artist = Artist.objects.create(**VARIOUS_ARTIST_DICT)
        logger.info("Created Various Artists placeholder")
    return artist
